Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Init ¶
func Init()
Init initializes a thread-safe singleton logger This would be called from a main method when the application starts up This function would ideally, take zap configuration, but is left out in favor of simplicity using the example logger.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.