Documentation
¶
Index ¶
- func BlockGeneration(bm *books.Accounts, sync *replication.Sync, inputConn net.PacketConn, ...)
- func BlockGenerationFaster(bm *books.Accounts, sync *replication.Sync, inputConn net.PacketConn, ...)
- func BlockSigner(bm *books.Accounts, sync *replication.Sync, replicationConn net.PacketConn, ...)
- func Messaging(bm *books.Accounts, inputConn net.PacketConn, outputConn net.PacketConn)
- func ProducerNode(producer replication.Node)
- func ProducerNodeWithServer(producer replication.Node)
- func RequestBlobs(sync *replication.Sync, frame *network.Frame, ...)
- func ServerNode(producer replication.Node, name string)
- func SignerNode(producer replication.Node, name string)
- func Synchronization(sync *replication.Sync, inputConn net.PacketConn, outputConn net.PacketConn)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BlockGeneration ¶
func BlockGeneration(bm *books.Accounts, sync *replication.Sync, inputConn net.PacketConn, outputConn net.PacketConn, reconstructionConn net.PacketConn, startingBlocksTotal uint64, db api.DataBase)
BlockGeneration is run on the producer node and is responsible for transaction processing and generating blocks
func BlockGenerationFaster ¶
func BlockGenerationFaster(bm *books.Accounts, sync *replication.Sync, inputConn net.PacketConn, outputConn net.PacketConn, reconstructionConn net.PacketConn, startingBlocksTotal uint64, db api.DataBase)
BlockGeneration is run on the producer node and is responsible for transaction processing and generating blocks
func BlockSigner ¶
func BlockSigner(bm *books.Accounts, sync *replication.Sync, replicationConn net.PacketConn, reconstructionConn net.PacketConn, outputConn net.PacketConn, db api.DataBase)
BlockSigner is run on every node and is responsible for block signer
func Messaging ¶
func Messaging(bm *books.Accounts, inputConn net.PacketConn, outputConn net.PacketConn)
Messaging is run on the producer or signer node and is responsible for Message processing
func ProducerNode ¶
func ProducerNode(producer replication.Node)
ProducerNode is responsible creating producer node
func ProducerNodeWithServer ¶
func ProducerNodeWithServer(producer replication.Node)
ProducerNodeWithServer is responsible createing producer node and run server on it
func RequestBlobs ¶
func RequestBlobs(sync *replication.Sync, frame *network.Frame, reconstructionConn net.PacketConn, outputConn net.PacketConn)
func ServerNode ¶
func ServerNode(producer replication.Node, name string)
ServerNode is responsible creating server node
func SignerNode ¶
func SignerNode(producer replication.Node, name string)
SignerNode is responsible creating signer
func Synchronization ¶
func Synchronization(sync *replication.Sync, inputConn net.PacketConn, outputConn net.PacketConn)
Synchronization is run on every node and is responsible for vital data replication
Types ¶
This section is empty.